--============================================================================= 
--
-- blinking led with different frequencies
--
--============================================================================= 

library ieee;
	use ieee.std_logic_1164.all;
	use ieee.std_logic_unsigned.all;

entity blink_led is

	port (		
		clk     		: in 	std_logic;
		resetn   	: in 	std_logic;
		user_btn   	: in 	std_logic;
		led1			: out std_logic;
		led2			: out std_logic
		
	);
	
end entity;

architecture behavioural of blink_led is

	signal cnt				: std_logic_vector(23 downto 0);
	signal blink_freq		: std_logic := '0';
	signal keyout			: std_logic;
	signal key_db			: std_logic := '0';
	signal dbcnt			: integer range 0 to 63 := 0;
	signal lastbtnstate	: std_logic := '0';
	
begin

	
	-- counter
	process(clk)
	begin
		if rising_edge(clk) then
			cnt <= cnt + 1;
		end if;
	end process;
	
	-- debounce key
   process 
	begin
      wait until rising_edge(clk);
      if (user_btn=key_db) then 
			dbcnt <= 0;
      else                   
			dbcnt <= dbcnt+1;
      end if;
      if (dbcnt=63) then 
			key_db <= user_btn; 
      end if;
   end process;
	
   keyout <= key_db;

	-- toggle through blink frequencies
	process(clk)
	begin
		if rising_edge(clk) then
				if (keyout = '1' and lastbtnstate = '0') then
					blink_freq <= not blink_freq;
				end if;
			lastbtnstate <= keyout;
		end if;
	end process;

	
	led1 <= cnt(23) when blink_freq = '0' else
				cnt(21) when blink_freq = '1'else 
				'1';
	led2 <= cnt(20) when resetn = '0' else 
				'0';


end architecture;